You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@guacamole.apache.org by jm...@apache.org on 2016/05/06 00:31:17 UTC

[1/2] incubator-guacamole-website git commit: The deploy branch is called asf-site, not asf-git.

Repository: incubator-guacamole-website
Updated Branches:
  refs/heads/master 2b797ccd2 -> f38297c1e


The deploy branch is called asf-site, not asf-git.


Project: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-website/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-website/commit/734e8c5b
Tree: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-website/tree/734e8c5b
Diff: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-website/diff/734e8c5b

Branch: refs/heads/master
Commit: 734e8c5b4783cf8b6d6a91a5d01a997d2a1e012f
Parents: 2b797cc
Author: Michael Jumper <mj...@apache.org>
Authored: Thu May 5 17:02:37 2016 -0700
Committer: Michael Jumper <mj...@apache.org>
Committed: Thu May 5 17:02:37 2016 -0700

----------------------------------------------------------------------
 README.md | 14 +++++++-------
 build.sh  | 10 +++++-----
 2 files changed, 12 insertions(+), 12 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-guacamole-website/blob/734e8c5b/README.md
----------------------------------------------------------------------
diff --git a/README.md b/README.md
index 53b4e70..1d57496 100644
--- a/README.md
+++ b/README.md
@@ -64,7 +64,7 @@ The build script handles three primary variations of common build tasks:
 
 1. The build itself, when invoked as `./build.sh`. This invokes Jekyll and recursively copies the `doc/` (part of the website source) and `_site/` (generated by Jekyll during the build) to the `content/` directory.
 2. Serving a local copy of the website, when invoked as `./build.sh PORT`.
-3. Staging local changes for commit to the special "asf-git" branch, when invoked as `./build.sh stage`. Once changes are committed and pushed to "asf-git", the public website will be updated by the ASF's gitpubsub.
+3. Staging local changes for commit to the special "asf-site" branch, when invoked as `./build.sh stage`. Once changes are committed and pushed to "asf-site", the public website will be updated by the ASF's gitpubsub.
 
 Testing changes locally
 -----------------------
@@ -93,16 +93,16 @@ Publishing changes
 
 Changes to the website are published using Apache's
 [gitpubsub](https://blogs.apache.org/infra/entry/git_based_websites_available)
-which relies on a special branch called "asf-git" containing *all website
+which relies on a special branch called "asf-site" containing *all website
 content* within a directory called `content/`.
 
-In the Apache Guacamole website repository, the "asf-git" branch is an "orphan"
+In the Apache Guacamole website repository, the "asf-site" branch is an "orphan"
 branch. The branch has no commits in common with the "master" branch and
 consists solely of the `content/` subdirectory. Updating the website thus
 involves:
 
 1. Making and testing your changes locally
-2. Replacing the entire contents of the `content/` directory within "asf-git"
+2. Replacing the entire contents of the `content/` directory within "asf-site"
    with the newly-generated `content/` directory.
 
 The `build.sh` script can take care of all this for you when invoked as
@@ -118,7 +118,7 @@ The `build.sh` script can take care of all this for you when invoked as
      Auto-regeneration: disabled. Use --watch to enable.
     Copying "doc/" and built site to "content/" ...
     Done. Full site is now within the "content/" directory.
-    Switched to branch 'asf-git'
+    Switched to branch 'asf-site'
     Removing README.md
     Removing _site/
     Content staged for commit. Use git to commit the results when ready.
@@ -130,7 +130,7 @@ The `build.sh` script can take care of all this for you when invoked as
     where PORT is the port number where the HTTP server should listen.
     $
 
-At this point, you will be on the "asf-git" branch and the current directory
+At this point, you will be on the "asf-site" branch and the current directory
 will contain only the `content/` subdirectory:
 
     $ ls
@@ -144,7 +144,7 @@ at a high level) using `git commit` and publish the update using
 `git push origin`.
 
 If you wish to unstage your changes, use `git reset --hard HEAD` to return to
-the original state of "asf-git", wiping out any local modifications made by
+the original state of "asf-site", wiping out any local modifications made by
 `build.sh`. You can then return to whichever branch you were working on with
 `git checkout`.
 

http://git-wip-us.apache.org/repos/asf/incubator-guacamole-website/blob/734e8c5b/build.sh
----------------------------------------------------------------------
diff --git a/build.sh b/build.sh
index f223b7d..aa7a2a0 100755
--- a/build.sh
+++ b/build.sh
@@ -30,7 +30,7 @@
 # The built results will be available in the "content" subdirectory of the
 # source tree.
 #
 # To stage the results for commit to the "asf-git" branch, specify "stage"
 # instead of an HTTP port number.
 #
 # USAGE:
@@ -131,7 +131,7 @@ serve() {
 }
 
 ##
 ## Stages the current build result for commit to the "asf-git" branch.
 ##
 stage() {
 
@@ -144,8 +144,8 @@ stage() {
     mv content/* "$TMP"
     rmdir content
 
-    # Change to asf-git
-    git checkout asf-git
+    # Change to asf-site
+    git checkout asf-site
 
     # Replace contents
     rm -rf content
@@ -172,7 +172,7 @@ if [ "$#" -gt 1 -o "$1" = "-h" ]; then
     log "    $0 -h       # Display this message"
     log "    $0          # Build website"
     log "    $0 PORT     # Build website and serve from the given PORT"
-    log "    $0 stage    # Build website and stage the contents for asf-git"
+    log "    $0 stage    # Build website and stage the contents for asf-site"
     exit 1
 fi
 


[2/2] incubator-guacamole-website git commit: Merge change to fix branch name.

Posted by jm...@apache.org.
Merge change to fix branch name.


Project: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-website/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-website/commit/f38297c1
Tree: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-website/tree/f38297c1
Diff: http://git-wip-us.apache.org/repos/asf/incubator-guacamole-website/diff/f38297c1

Branch: refs/heads/master
Commit: f38297c1ef3c3348971553386a8340991aa9ca21
Parents: 2b797cc 734e8c5
Author: James Muehlner <ja...@guac-dev.org>
Authored: Thu May 5 17:30:46 2016 -0700
Committer: James Muehlner <ja...@guac-dev.org>
Committed: Thu May 5 17:30:46 2016 -0700

----------------------------------------------------------------------
 README.md | 14 +++++++-------
 build.sh  | 10 +++++-----
 2 files changed, 12 insertions(+), 12 deletions(-)
----------------------------------------------------------------------
@@ -30,7 +30,7 @@
 # source tree.
 #
-# To stage the results for commit to the "asf-git" branch, specify "stage"
+# To stage the results for commit to the "asf-site branch, specify "stage"
 # instead of an HTTP port number.
 #
@@ -131,7 +131,7 @@ serve() {
 
 ##
-## Stages the current build result for commit to the "asf-git" branch.
+## Stages the current build result for commit to the "asf-site" branch.
 ##
 stage() {